:::{include} ../README.md
:::

:::{toctree}
:caption: Contents
:maxdepth: 2

topics/index
cli/index
contributing/index
changelog
:::

Copyright (c) 2022 Open Contracting Partnership, released under the MIT license
